@@ -38,7 +38,7 @@ def open_url(url: str):
 @lru_cache(maxsize=None)
 def retrieve_installed_version() -> str:
     package_info = subprocess.run(
-        [sys.executable, "-m", "pip", "show", "b0mb3r"],
+        [sys.executable, "-m", "pip", "show", "db0mb3r"],
         stdout=subprocess.PIPE,
         check=True,
     )
